<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\162\x64\120\x72\x65\163\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\157\144\145\x6a\163"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\x74\141\x74\x69\143"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\x79\x74\150\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\145\166\x65\162\163\145\x50\162\157\170\x79"; private const VARNISH_CACHE_SERVER = "\61\62\67\56\x30\56\60\56\x31\x3a\x36\x30\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\106\123\137\x4d\x45\x54\110\x4f\x44" => ["\166\141\x6c\165\x65" => "\x64\x69\x72\x65\143\x74", "\x72\x61\x77" => false], "\127\120\137\104\105\x42\x55\107\137\x44\x49\123\x50\114\x41\131" => ["\166\141\154\x75\x65" => "\146\141\x6c\x73\x65", "\162\141\167" => true], "\127\x50\137\104\105\102\125\x47\x5f\x4c\x4f\107" => ["\x76\141\154\x75\x65" => "\x74\162\165\x65", "\162\x61\167" => true], "\103\x4f\116\103\101\124\105\116\x41\124\x45\x5f\123\x43\122\111\x50\124\123" => ["\x76\x61\154\165\145" => "\x66\x61\154\163\x65", "\x72\x61\167" => true], "\101\x55\124\117\123\x41\126\105\137\x49\x4e\124\105\122\126\101\114" => ["\x76\141\154\165\145" => 600, "\162\141\167" => true], "\x57\120\137\120\x4f\123\124\x5f\122\105\126\111\x53\111\117\116\123" => ["\166\141\154\x75\x65" => 5, "\162\x61\167" => true], "\105\115\120\124\x59\x5f\x54\122\101\123\x48\x5f\104\101\131\123" => ["\166\141\154\165\145" => 21, "\x72\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\120\x5f\x41\114\x4c\117\127\137\115\125\114\x54\111\123\x49\x54\x45" => ["\166\x61\x6c\165\145" => "\164\x72\x75\x65", "\x72\x61\167" => true], "\x4d\x55\114\124\x49\123\x49\x54\x45" => ["\166\x61\x6c\x75\145" => "\x74\x72\165\x65", "\x72\x61\x77" => true], "\x53\x55\x42\x44\117\x4d\101\x49\116\137\111\x4e\123\124\x41\114\114" => ["\x76\141\x6c\165\x65" => "\x66\x61\154\163\145", "\162\141\167" => true], "\x44\117\x4d\x41\x49\x4e\x5f\103\125\122\122\x45\x4e\124\x5f\123\x49\124\105" => ["\166\x61\154\165\x65" => '', "\x72\x61\x77" => false], "\120\x41\124\x48\137\x43\125\x52\x52\x45\116\x54\x5f\123\x49\x54\x45" => ["\x76\141\154\165\145" => "\57", "\162\x61\167" => false], "\123\x49\x54\x45\137\x49\104\x5f\x43\x55\122\x52\105\x4e\x54\137\123\111\x54\105" => ["\x76\x61\154\x75\145" => 1, "\162\141\167" => true], "\x42\114\x4f\107\137\x49\104\x5f\x43\125\x52\x52\105\x4e\x54\137\123\111\x54\x45" => ["\166\x61\x6c\165\145" => 1, "\162\141\167" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto E983c; Caea4: parent::__construct($translator, $logger); goto fe406; b0717: $this->databaseUserEntityManager = $databaseUserEntityManager; goto e668c; Db34c: $this->siteEntityManager = $siteEntityManager; goto Eb3d7; Cb521: $this->validator = $validator; goto Caea4; E983c: $this->configManager = $configManager; goto Db34c; F0e8b: $this->databaseEntityManager = $databaseEntityManager; goto b0717; e668c: $this->databaseServerEntityManager = $databaseServerEntityManager; goto ded56; f5be7: $this->domainNameParser = $domainNameParser; goto Cb521; Eb3d7: $this->certificateEntityManager = $certificateEntityManager; goto F0e8b; ded56: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto f5be7; fe406: } public function index(Request $request) : Response { goto e323b; b3a3d: c3629: goto Eec65; Eec65: return $response; goto D93f2; E1593: $user = $this->getUser(); goto fc9ca; de013: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\x69\164\x65\163")); goto d9144; fc9ca: $response = $this->render("\x46\162\157\156\164\145\x6e\x64\x2f\x53\x69\x74\145\57\116\145\167\57\x69\x6e\x64\x65\170\56\150\x74\x6d\154\56\164\167\x69\147", ["\x75\163\145\x72" => $user]); goto b3a3d; e323b: $hasPermissions = $this->hasPermissions(); goto ce2e8; ce2e8: if (true === $hasPermissions) { goto Caaa1; } goto de013; d9144: goto c3629; goto fbf29; fbf29: Caaa1: goto E1593; D93f2: } public function newPythonSite(Request $request) : Response { goto a81fd; fcd6e: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\163\x69\164\x65\x73")); goto d72bd; C0e64: $form->handleRequest($request); goto d0581; d0581: if (!(true === $form->isSubmitted())) { goto ded42; } goto dcf80; b9ed4: ded42: goto f1914; Be83d: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto db8db; } goto C0e64; f1914: db8db: goto F5a59; d72bd: goto C69e6; goto B1ca3; dcf80: $response = $this->handleCreatePythonSiteForm($request, $form); goto Ee304; D285e: $form = $this->createPythonSiteForm($pythonSettings); goto Be83d; Ee304: if (!(false === is_null($response))) { goto a96c7; } goto c252e; B731e: return $response; goto d2d01; eeebc: $user = $this->getUser(); goto E3684; B1ca3: b25f3: goto eeebc; E15e3: a96c7: goto b9ed4; c0c8b: if (true === $hasPermissions) { goto b25f3; } goto fcd6e; E332d: C69e6: goto B731e; c252e: return $response; goto E15e3; F5a59: $response = $this->render("\106\x72\x6f\156\164\145\156\x64\x2f\123\x69\x74\145\57\x4e\145\167\57\160\x79\x74\x68\157\x6e\x2e\150\164\155\154\x2e\164\167\151\147", ["\165\163\x65\x72" => $user, "\146\157\162\x6d" => $form->createView(), "\146\157\162\x6d\105\x72\162\157\x72\x73" => $this->formErrors]); goto E332d; E3684: $pythonSettings = new PythonSettingsEntity(); goto D285e; a81fd: $hasPermissions = $this->hasPermissions(); goto c0c8b; d2d01: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto E2c35; E2c35: $form = $this->createForm("\x41\x70\x70\x5c\x46\157\x72\x6d\x5c\x53\151\164\x65\116\x65\167\x50\x79\x74\150\157\x6e\x54\x79\x70\145", $pythonSettings, ["\141\x63\x74\151\157\156" => $this->generateUrl("\143\154\160\137\x73\151\x74\145\137\160\x79\x74\x68\157\x6e\137\x6e\x65\167"), "\155\x65\164\x68\157\x64" => "\120\x4f\123\x54", "\141\164\164\x72" => ["\151\144" => "\x6e\145\x77\x2d\x70\x79\164\150\x6f\156\x2d\x73\x69\x74\x65\x2d\146\157\x72\155"]]); goto E48b7; B8317: return $form; goto B96b6; E48b7: $form->add("\163\165\142\155\x69\164", SubmitType::class, ["\x61\x74\164\x72" => ["\143\154\x61\163\163" => "\142\x74\156\x20\x62\x74\x6e\55\x6c\x67\x20\x62\164\x6e\x2d\x62\154\165\145"], "\x6c\141\x62\x65\154" => "\x43\x72\145\141\164\145"]); goto B8317; B96b6: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto b6bba; Da651: cb4ae: goto A7402; B00db: fe09e: goto c2cbc; De18b: goto fe09e; goto Da651; A7402: try { goto c4d3e; f63aa: e762b: goto d2c13; e5b32: $siteUser = $form->get("\x73\151\x74\145\x55\x73\145\x72")->getData(); goto f16df; c4d3e: $session = $request->getSession(); goto fb2e5; e65b4: $session->getFlashBag()->set("\163\x75\x63\x63\x65\163\163", $this->translator->trans("\123\151\164\145\40\150\141\x73\x20\x62\x65\145\x6e\40\143\x72\x65\x61\x74\145\144\56")); goto E9c42; F009e: $user = $this->getUser(); goto E0c0a; c372d: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E5438; Bfbac: $eventData = ["\x73\151\x74\x65" => $domainName, "\x73\x69\164\x65\x55\x73\x65\x72" => $siteUser, "\160\x79\164\150\x6f\x6e\x56\145\x72\163\x69\x6f\x6e" => $pythonVersion, "\160\x6f\162\x74" => $port]; goto be629; A908a: $pythonVersion = $form->get("\160\x79\164\x68\x6f\156\126\145\162\x73\x69\x6f\x6e")->getData(); goto Dfb35; E5438: if (false === is_null($vhostTemplateEntity)) { goto cd2ab; } goto Fe869; Fe869: throw new \Exception(sprintf("\x56\x68\157\x73\x74\40\x74\145\x6d\160\x6c\x61\164\x65\x20\42\45\163\x22\40\156\x6f\x74\x20\x66\x6f\165\x6e\144\x2e", $vhostTemplateName)); goto Bc76b; A7aae: cd2ab: goto F009e; f16df: $siteUserPassword = $form->get("\163\x69\164\145\x55\x73\x65\162\x50\141\x73\x73\x77\x6f\x72\x64")->getData(); goto D5127; E9c42: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\x69\164\145\x73")); goto Cde2c; D5127: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto c372d; E0c0a: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto Bfbac; Cde2c: return $response; goto f63aa; be629: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto e65b4; Bc76b: goto e762b; goto A7aae; Dfb35: $port = $form->get("\160\157\162\164")->getData(); goto e5b32; fb2e5: $domainName = $form->get("\x64\157\x6d\141\x69\x6e\x4e\141\x6d\145")->getData(); goto A908a; d2c13: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\x67\145\162", $this->translator->trans("\x41\156\x20\145\162\162\157\x72\40\150\141\x73\40\x6f\x63\x63\165\162\162\x65\x64\54\x20\145\x72\x72\x6f\x72\x20\x6d\x65\163\163\x61\x67\145\72\40\45\x65\162\x72\157\162\x4d\x65\163\x73\x61\x67\x65\x25", ["\x25\145\162\162\x6f\x72\x4d\x65\x73\163\141\147\x65\45" => $e->getMessage()])); } goto B00db; D534e: $this->formErrors = $this->getErrorMessages($form); goto De18b; b6bba: if (true === $form->isValid()) { goto cb4ae; } goto D534e; c2cbc: } public function newReverseProxy(Request $request) : Response { goto Ae01e; bd50a: goto E58d4; goto bcabb; Ab45f: if (!(true === $request->isMethod("\x50\117\123\x54"))) { goto F47e0; } goto C2325; ac571: $response = $this->redirect($this->generateUrl("\x63\154\160\137\x73\151\164\145\163")); goto bd50a; f1f5a: $form = $this->createReverseProxyForm(); goto Ab45f; C139a: if (!(false === is_null($response))) { goto Dd121; } goto caf59; bcabb: Aea24: goto Dd9c8; e0f9c: Dd121: goto cb8b4; a4e56: F47e0: goto Da825; f88df: if (true === $hasPermissions) { goto Aea24; } goto ac571; Dd9c8: $user = $this->getUser(); goto f1f5a; C2325: $form->handleRequest($request); goto E0c0b; Ae01e: $hasPermissions = $this->hasPermissions(); goto f88df; Da825: $response = $this->render("\106\x72\157\156\x74\145\x6e\x64\x2f\x53\x69\164\145\x2f\116\x65\167\x2f\162\145\166\x65\x72\x73\x65\x2d\x70\x72\x6f\x78\x79\56\150\x74\155\x6c\x2e\x74\167\x69\147", ["\165\163\x65\162" => $user, "\146\157\162\x6d" => $form->createView(), "\146\x6f\x72\155\x45\x72\x72\157\162\163" => $this->formErrors]); goto Cffb3; E0c0b: if (!(true === $form->isSubmitted())) { goto Ea85e; } goto B7c18; B7c18: $response = $this->handleReverseProxyForm($request, $form); goto C139a; c3d40: return $response; goto Cf249; cb8b4: Ea85e: goto a4e56; caf59: return $response; goto e0f9c; Cffb3: E58d4: goto c3d40; Cf249: } private function createReverseProxyForm() : Form { goto D1de6; D1de6: $form = $this->createForm("\101\160\x70\134\x46\157\162\155\x5c\x53\151\164\145\x4e\145\x77\x52\145\x76\x65\x72\163\145\x50\162\157\x78\171\124\171\160\x65", [], ["\141\143\164\151\x6f\x6e" => $this->generateUrl("\143\x6c\160\137\163\x69\x74\x65\137\162\x65\x76\145\x72\x73\145\x5f\x70\x72\x6f\170\171\137\156\x65\x77"), "\155\145\164\150\x6f\144" => "\x50\x4f\123\x54", "\x61\x74\164\x72" => ["\x69\x64" => "\x6e\x65\167\x2d\162\x65\166\x65\162\x73\x65\55\160\x72\x6f\170\171\55\x66\x6f\x72\x6d"]]); goto Dc93c; Dc93c: $form->add("\x73\165\x62\155\x69\164", SubmitType::class, ["\141\x74\164\162" => ["\x63\x6c\x61\163\163" => "\x62\164\x6e\40\142\x74\x6e\55\x6c\x67\40\x62\x74\156\x2d\x62\154\165\145"], "\154\141\142\x65\x6c" => "\x43\162\x65\141\164\145"]); goto f7227; f7227: return $form; goto Bfb2e; Bfb2e: } private function handleReverseProxyForm(Request $request, Form $form) { goto E769e; f9c4c: $this->formErrors = $this->getErrorMessages($form); goto Be5c3; c0104: try { goto F7346; f2b70: return $response; goto f9fca; be3b2: $domainName = $form->get("\144\x6f\155\x61\x69\x6e\116\x61\x6d\x65")->getData(); goto f26b6; d54a2: goto B0f56; goto bb8db; Af31b: $user = $this->getUser(); goto F431f; f9fca: B0f56: goto d84ad; E6a4c: $reverseProxyUrl = $form->get("\x72\x65\166\x65\x72\163\145\120\x72\157\170\171\x55\162\154")->getData(); goto F48e1; C5be9: $session->getFlashBag()->set("\x73\x75\143\x63\145\163\x73", $this->translator->trans("\x52\145\x76\x65\x72\x73\x65\40\120\162\x6f\x78\171\40\x68\x61\163\40\x62\145\145\156\40\143\162\145\x61\164\x65\144\x2e")); goto b2aa4; b2aa4: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\163\x69\x74\x65\x73")); goto f2b70; bb8db: E53e7: goto Af31b; B08b6: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E9ce0; c7608: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\x69\x74\145\x55\x73\145\x72" => $siteUser, "\x72\145\x76\145\x72\x73\145\120\x72\x6f\170\x79\x55\x72\154" => $reverseProxyUrl]; goto b94c6; f26b6: $siteUser = $form->get("\x73\151\x74\x65\125\x73\145\x72")->getData(); goto C9abf; F48e1: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto B08b6; e53b5: throw new \Exception(sprintf("\x56\150\x6f\163\x74\40\164\x65\x6d\x70\x6c\x61\164\145\x20\x22\x25\x73\42\40\x6e\157\164\40\x66\x6f\x75\x6e\144\x2e", $vhostTemplateName)); goto d54a2; b94c6: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto C5be9; C9abf: $siteUserPassword = $form->get("\163\x69\164\145\x55\x73\x65\x72\x50\x61\163\x73\x77\157\x72\x64")->getData(); goto E6a4c; E9ce0: if (false === is_null($vhostTemplateEntity)) { goto E53e7; } goto e53b5; F7346: $session = $request->getSession(); goto be3b2; F431f: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto c7608; d84ad: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\145\x72", $this->translator->trans("\101\156\40\x65\x72\162\x6f\x72\40\x68\x61\163\40\x6f\143\143\x75\x72\x72\145\144\x2c\x20\145\162\x72\157\x72\40\155\145\x73\163\141\x67\145\72\40\45\145\162\162\x6f\x72\x4d\145\x73\x73\141\x67\x65\x25", ["\45\145\162\x72\x6f\162\x4d\145\163\x73\141\147\145\45" => $e->getMessage()])); } goto fbe85; fbe85: Bc036: goto Ec8ca; E769e: if (true === $form->isValid()) { goto E841e; } goto f9c4c; Be5c3: goto Bc036; goto d6688; d6688: E841e: goto c0104; Ec8ca: } public function newNodejsSite(Request $request) : Response { goto d158a; E76e8: $response = $this->render("\x46\x72\x6f\x6e\164\145\x6e\144\57\123\151\x74\x65\x2f\x4e\x65\167\x2f\x6e\157\x64\x65\x6a\163\56\x68\x74\x6d\154\56\164\x77\151\x67", ["\165\163\x65\162" => $user, "\146\157\162\155" => $form->createView(), "\146\157\x72\x6d\105\x72\x72\157\162\x73" => $this->formErrors]); goto E1d8b; E1d8b: cf1e7: goto b8d1c; E22ae: bf723: goto Ee271; A27df: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto Ac4b7; } goto d939d; ac437: goto cf1e7; goto E22ae; ea096: if (!(false === is_null($response))) { goto Eccf7; } goto fcfeb; fcfeb: return $response; goto f71ef; d158a: $hasPermissions = $this->hasPermissions(); goto e08c4; b8d1c: return $response; goto E459e; d939d: $form->handleRequest($request); goto f6923; A329b: $response = $this->handleCreateNodejsSiteForm($request, $form); goto ea096; f71ef: Eccf7: goto dc0ed; dc0ed: B5c5d: goto F89e5; e08c4: if (true === $hasPermissions) { goto bf723; } goto f2ace; F89e5: Ac4b7: goto E76e8; A824a: $form = $this->createNodejsSiteForm($nodejsSettings); goto A27df; f2ace: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\151\x74\x65\163")); goto ac437; Ee271: $user = $this->getUser(); goto B56a3; B56a3: $nodejsSettings = new NodejsSettingsEntity(); goto A824a; f6923: if (!(true === $form->isSubmitted())) { goto B5c5d; } goto A329b; E459e: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto c1446; De391: return $form; goto e2296; c1446: $form = $this->createForm("\x41\x70\x70\134\106\x6f\162\155\134\123\x69\x74\145\x4e\x65\x77\116\157\144\x65\152\163\x54\x79\160\x65", $nodejsSettings, ["\141\143\x74\151\x6f\156" => $this->generateUrl("\143\x6c\x70\137\x73\x69\164\x65\x5f\x6e\x6f\144\x65\152\x73\x5f\x6e\x65\x77"), "\x6d\145\x74\x68\x6f\x64" => "\x50\117\x53\124", "\141\x74\x74\x72" => ["\x69\144" => "\156\x65\167\55\x6e\x6f\x64\x65\152\163\x2d\163\151\x74\x65\55\x66\x6f\162\x6d"]]); goto Cb4c3; Cb4c3: $form->add("\x73\x75\x62\155\x69\164", SubmitType::class, ["\x61\164\x74\162" => ["\143\154\x61\x73\x73" => "\142\164\156\x20\142\x74\x6e\55\154\147\x20\142\164\156\x2d\x62\154\165\x65"], "\154\x61\142\x65\154" => "\x43\162\145\x61\164\x65"]); goto De391; e2296: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto E5b5b; E5b5b: if (true === $form->isValid()) { goto E5b41; } goto D86a4; c6df5: E5b41: goto a2acf; a2acf: try { goto ed228; d3000: goto df40d; goto e6103; D060d: if (false === is_null($vhostTemplateEntity)) { goto B6b06; } goto F6b20; ed228: $session = $request->getSession(); goto b8b5e; a3682: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto eac7f; b8b5e: $domainName = $form->get("\144\x6f\155\x61\x69\x6e\116\141\x6d\145")->getData(); goto c602a; e1e5e: $siteUser = $form->get("\163\151\x74\x65\125\x73\145\x72")->getData(); goto e523f; eac7f: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto D060d; e523f: $siteUserPassword = $form->get("\x73\151\164\x65\x55\163\145\162\x50\141\163\163\x77\x6f\x72\144")->getData(); goto a3682; Fb01c: $eventData = ["\163\151\164\145" => $domainName, "\163\x69\x74\x65\x55\163\145\162" => $siteUser, "\x6e\157\x64\x65\152\163\x56\145\162\163\151\157\x6e" => $nodejsVersion, "\160\157\x72\164" => $port]; goto da53b; e6103: B6b06: goto f8371; F7cd2: $session->getFlashBag()->set("\x73\165\143\143\145\163\x73", $this->translator->trans("\123\151\x74\145\x20\150\141\163\x20\142\x65\x65\x6e\40\143\162\145\141\164\x65\144\56")); goto ba6a8; f8371: $user = $this->getUser(); goto c3e7b; c602a: $nodejsVersion = $form->get("\156\157\x64\x65\x6a\163\x56\x65\162\163\x69\x6f\x6e")->getData(); goto b03f2; c3e7b: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto Fb01c; da53b: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto F7cd2; F6b20: throw new \Exception(sprintf("\126\x68\x6f\163\164\40\164\145\x6d\160\x6c\x61\x74\145\x20\42\x25\163\42\x20\x6e\157\x74\x20\146\x6f\x75\156\x64\56", $vhostTemplateName)); goto d3000; ba6a8: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\x69\164\145\163")); goto A2dcd; A2dcd: return $response; goto de5c6; b03f2: $port = $form->get("\160\157\x72\x74")->getData(); goto e1e5e; de5c6: df40d: goto Ddce6; Ddce6: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\162", $this->translator->trans("\101\156\40\145\x72\x72\157\x72\x20\x68\x61\163\x20\157\143\x63\x75\162\x72\x65\144\54\x20\145\x72\162\157\x72\40\155\145\163\163\x61\x67\145\x3a\x20\45\x65\x72\x72\157\x72\x4d\x65\x73\163\x61\147\145\45", ["\45\x65\162\162\x6f\162\115\x65\x73\163\x61\x67\145\x25" => $e->getMessage()])); } goto A4e04; bd791: goto C40a2; goto c6df5; D86a4: $this->formErrors = $this->getErrorMessages($form); goto bd791; A4e04: C40a2: goto dab32; dab32: } public function newStaticSite(Request $request) : Response { goto d1022; D005b: Fc42a: goto E8a7a; C5bcf: goto Abf0e; goto D005b; E8a7a: $user = $this->getUser(); goto Dd098; B8a27: $response = $this->render("\106\x72\x6f\x6e\164\145\x6e\144\x2f\x53\x69\x74\x65\x2f\x4e\145\x77\x2f\x73\x74\x61\x74\x69\143\56\x68\x74\x6d\154\56\164\x77\151\147", ["\x75\163\145\x72" => $user, "\x66\x6f\x72\155" => $form->createView(), "\146\x6f\x72\x6d\105\162\x72\x6f\162\x73" => $this->formErrors]); goto d5138; A16f7: if (true === $hasPermissions) { goto Fc42a; } goto Be021; Be021: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\x69\164\145\163")); goto C5bcf; d1022: $hasPermissions = $this->hasPermissions(); goto A16f7; b8b79: d5c96: goto Acfc8; Cb858: return $response; goto b8b79; a384b: $form->handleRequest($request); goto A84b2; D6639: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto F3d9c; } goto a384b; C79f7: $response = $this->handleCreateStaticSiteForm($request, $form); goto da3da; Dd098: $form = $this->createStaticSiteForm(); goto D6639; F7c84: return $response; goto e53c0; E691a: F3d9c: goto B8a27; A84b2: if (!(true === $form->isSubmitted())) { goto Ef13b; } goto C79f7; da3da: if (!(false === is_null($response))) { goto d5c96; } goto Cb858; Acfc8: Ef13b: goto E691a; d5138: Abf0e: goto F7c84; e53c0: } private function createStaticSiteForm() : Form { goto B137b; F696e: $form->add("\163\x75\142\155\x69\x74", SubmitType::class, ["\141\164\164\162" => ["\143\x6c\x61\x73\163" => "\142\164\156\x20\x62\x74\156\x2d\x6c\x67\40\142\164\x6e\55\x62\x6c\x75\145"], "\x6c\x61\142\145\x6c" => "\x43\x72\x65\141\164\145"]); goto Fb410; Fb410: return $form; goto a35b9; B137b: $form = $this->createForm("\101\160\160\134\106\x6f\162\x6d\x5c\x53\151\164\x65\116\x65\167\123\x74\x61\164\x69\143\x54\171\160\x65", [], ["\141\x63\x74\151\157\156" => $this->generateUrl("\143\154\160\137\163\x69\164\145\137\x73\164\141\x74\x69\x63\137\x6e\x65\x77"), "\155\x65\164\x68\x6f\144" => "\120\x4f\123\124", "\141\164\x74\162" => []]); goto F696e; a35b9: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto B3b86; c9f1c: c1945: goto D3156; ec949: try { goto Dd27a; adea6: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto E0657; E0657: if (false === is_null($vhostTemplateEntity)) { goto B788f; } goto cae66; Bdd9c: $session->getFlashBag()->set("\x73\165\x63\143\145\163\x73", $this->translator->trans("\x53\x69\x74\145\x20\x68\x61\x73\x20\142\x65\145\156\40\143\162\145\x61\164\x65\x64\56")); goto D6750; D4483: $domainName = $form->get("\x64\157\x6d\141\151\156\116\141\x6d\x65")->getData(); goto ca64e; bccb4: c9e76: goto de1c7; F1aef: return $response; goto bccb4; ab768: goto c9e76; goto A7a13; ff7a2: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto adea6; e1729: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto dc769; D6750: $response = $this->redirect($this->generateUrl("\143\x6c\160\137\x73\x69\164\x65\x73")); goto F1aef; Dd27a: $session = $request->getSession(); goto D4483; ca64e: $siteUser = $form->get("\x73\x69\x74\145\x55\x73\x65\162")->getData(); goto c895e; dc769: $eventData = ["\x73\151\164\x65" => $domainName, "\163\x69\164\145\x55\x73\x65\162" => $siteUser]; goto Ec063; Ec063: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Bdd9c; cae66: throw new \Exception(sprintf("\126\x68\x6f\x73\164\40\x74\x65\155\160\x6c\141\x74\145\x20\x22\45\x73\42\x20\x6e\157\164\x20\x66\157\165\x6e\x64\56", $vhostTemplateName)); goto ab768; A7a13: B788f: goto baff5; c895e: $siteUserPassword = $form->get("\163\151\x74\x65\x55\163\x65\x72\x50\x61\x73\x73\x77\157\x72\144")->getData(); goto ff7a2; baff5: $user = $this->getUser(); goto e1729; de1c7: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\147\145\162", $this->translator->trans("\x41\156\40\x65\162\x72\x6f\162\x20\150\141\x73\40\157\143\143\x75\162\162\145\x64\x2c\40\x65\162\162\157\162\x20\155\145\x73\x73\141\x67\145\x3a\40\45\x65\162\162\157\162\x4d\x65\x73\163\141\147\145\45", ["\45\145\162\x72\x6f\x72\115\145\163\163\x61\147\x65\45" => $e->getMessage()])); } goto c9f1c; Edeb6: bde7a: goto ec949; Abe8b: goto c1945; goto Edeb6; B3b86: if (true === $form->isValid()) { goto bde7a; } goto d69c7; d69c7: $this->formErrors = $this->getErrorMessages($form); goto Abe8b; D3156: } public function newPhpSite(Request $request) : Response { goto C2f78; F2093: B5713: goto fef2f; b2236: goto B7d3b; goto fea9a; afbed: B7d3b: goto C434d; Eb7cc: a0c6a: goto F2093; f3c7f: $response = $this->redirect($this->generateUrl("\143\154\x70\137\163\151\164\x65\163")); goto b2236; fc9b0: return $response; goto Eb7cc; fea9a: F4069: goto Cdf68; F523c: $response = $this->handleCreatePhpSiteForm($request, $form); goto b246f; E2af9: if (!(true === $request->isMethod("\x50\117\x53\x54"))) { goto B8d9c; } goto D1d91; D1d91: $form->handleRequest($request); goto d4643; fef2f: B8d9c: goto b5965; b5965: $response = $this->render("\x46\162\157\x6e\164\145\x6e\x64\57\123\151\164\x65\57\116\145\167\57\x70\x68\x70\x2e\150\164\155\x6c\56\x74\x77\151\147", ["\165\163\145\162" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\x6d\x45\162\x72\x6f\x72\163" => $this->formErrors]); goto afbed; b246f: if (!(false === is_null($response))) { goto a0c6a; } goto fc9b0; Cdf68: $user = $this->getUser(); goto d7f6b; C2f78: $hasPermissions = $this->hasPermissions(); goto C666c; d7f6b: $form = $this->createPhpSiteForm(); goto E2af9; C666c: if (true === $hasPermissions) { goto F4069; } goto f3c7f; C434d: return $response; goto f1e09; d4643: if (!(true === $form->isSubmitted())) { goto B5713; } goto F523c; f1e09: } private function createPhpSiteForm() : Form { goto E2205; B86ed: return $form; goto Ce646; E2205: $form = $this->createForm("\101\x70\160\134\x46\x6f\162\155\134\x53\151\x74\145\x4e\x65\167\x50\x68\x70\124\x79\160\x65", [], ["\x61\x63\x74\x69\157\x6e" => $this->generateUrl("\143\154\160\x5f\x73\x69\164\x65\137\x70\150\x70\137\156\145\167"), "\x6d\145\x74\150\x6f\x64" => "\x50\117\x53\x54", "\x61\x74\164\x72" => []]); goto Fc493; Fc493: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\x61\x74\164\x72" => ["\143\x6c\x61\163\x73" => "\142\164\156\40\142\x74\156\x2d\154\x67\40\142\x74\156\55\142\154\165\x65"], "\154\x61\x62\145\x6c" => "\103\x72\145\x61\164\x65"]); goto B86ed; Ce646: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto bf684; c83f4: cc305: goto ec548; Daf2c: $this->formErrors = $this->getErrorMessages($form); goto c26c9; c26c9: goto a75c1; goto c83f4; bf684: if (true === $form->isValid()) { goto cc305; } goto Daf2c; De66e: a75c1: goto A92bc; ec548: try { goto d7529; b3ae3: $user = $this->getUser(); goto a5949; f540f: if (false === is_null($vhostTemplateEntity)) { goto E4ad8; } goto Ed37d; fd8e3: $varnishCacheSettings = []; goto B876b; Ed37d: throw new \Exception(sprintf("\126\x68\x6f\x73\x74\x20\x74\145\155\x70\x6c\x61\x74\x65\x20\x22\45\x73\42\40\x6e\x6f\164\40\146\157\x75\156\x64\x2e", $vhostTemplateName)); goto e6856; E23e5: $siteUserPassword = $form->get("\163\x69\164\x65\x55\163\145\x72\x50\x61\163\x73\167\157\x72\x64")->getData(); goto fef02; baf54: $session->getFlashBag()->set("\x73\165\x63\x63\x65\163\x73", $this->translator->trans("\123\x69\x74\145\x20\150\141\x73\x20\142\145\145\156\40\x63\x72\145\141\164\x65\144\56")); goto cde5b; A3ad9: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto e5b7f; B876b: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto a532c; } goto A3ad9; D3170: $siteUser = $form->get("\163\x69\164\x65\x55\x73\x65\x72")->getData(); goto E23e5; e5b7f: a532c: goto B5589; a5949: $rootDirectory = $domainName; goto F99ce; Aec6b: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto baf54; F99ce: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto dcd61; } goto Ec7e2; F290c: return $response; goto D0189; d7529: $session = $request->getSession(); goto D3404; D63fe: $eventData = ["\163\x69\x74\145" => $domainName, "\166\x68\x6f\x73\164\124\145\155\160\x6c\x61\x74\145\116\x61\155\145" => $vhostTemplateName, "\160\x68\160\x56\x65\x72\163\x69\157\x6e" => $phpVersion, "\x73\x69\164\x65\125\x73\x65\x72" => $siteUser]; goto Aec6b; cde5b: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\151\x74\145\x73")); goto F290c; e6856: goto d6305; goto c1a92; d370a: $domainName = $form->get("\144\x6f\x6d\141\151\x6e\116\x61\x6d\145")->getData(); goto Ebeaa; c1a92: E4ad8: goto b3ae3; Ebeaa: $phpVersion = $form->get("\x70\150\160\x56\x65\x72\163\151\x6f\156")->getData(); goto D3170; Ec7e2: $rootDirectory = sprintf("\x25\x73\57\45\x73", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\x2f")); goto Ef02b; D3404: $vhostTemplateName = $form->get("\x61\160\160\x6c\151\x63\141\x74\x69\x6f\156")->getData(); goto d370a; D0189: d6305: goto A017a; fef02: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto f540f; B5589: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto D63fe; Ef02b: dcd61: goto fd8e3; A017a: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\162", $this->translator->trans("\101\x6e\40\x65\x72\162\157\162\x20\x68\141\163\40\157\143\143\x75\162\x72\x65\144\x2c\40\x65\x72\162\157\x72\x20\x6d\145\x73\x73\141\147\x65\x3a\40\45\145\162\x72\157\x72\115\145\163\x73\x61\147\x65\x25", ["\45\x65\x72\162\157\162\x4d\145\163\163\x61\x67\145\x25" => $e->getMessage()])); } goto De66e; A92bc: } public function newWordPressSite(Request $request) : Response { goto C0b8d; Ea829: if (true === $hasPermissions) { goto ca52a; } goto d6109; E7909: $form = $this->createWordPressSiteForm(); goto e99f8; da9ac: return $response; goto cf163; af292: b9cb7: goto C5819; d239a: if (!(false === is_null($response))) { goto a8592; } goto da9ac; a7362: return $response; goto Bdcb1; d6109: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\x69\164\145\163")); goto Bc0d0; ebb6b: $form->handleRequest($request); goto bc0c2; Dc610: $user = $this->getUser(); goto E7909; bc0c2: if (!(true === $form->isSubmitted())) { goto b9cb7; } goto e7005; Ad17c: $response = $this->render("\106\x72\157\156\164\145\156\x64\x2f\123\x69\x74\145\57\x4e\x65\x77\x2f\x77\157\162\144\x70\162\x65\163\x73\56\150\164\155\x6c\x2e\164\x77\x69\x67", ["\165\163\145\162" => $user, "\x66\157\x72\155" => $form->createView(), "\x66\x6f\x72\155\105\162\x72\157\x72\x73" => $this->formErrors]); goto bf268; C0b8d: $hasPermissions = $this->hasPermissions(); goto Ea829; e7005: $response = $this->handleCreateWordPressSiteForm($request, $form); goto d239a; C5819: f456a: goto Ad17c; e99f8: if (!(true === $request->isMethod("\120\x4f\123\124"))) { goto f456a; } goto ebb6b; cf163: a8592: goto af292; Bc0d0: goto b9457; goto D5415; bf268: b9457: goto a7362; D5415: ca52a: goto Dc610; Bdcb1: } private function createWordPressSiteForm() : Form { goto E5be9; fd6d3: return $form; goto d64a0; E5be9: $form = $this->createForm("\x41\160\160\x5c\x46\157\162\x6d\x5c\123\151\164\145\116\x65\x77\127\x6f\x72\144\x50\x72\x65\163\163\x54\x79\160\x65", [], ["\141\x63\x74\x69\x6f\156" => $this->generateUrl("\143\154\160\x5f\x73\x69\164\x65\x5f\x77\x6f\162\x64\x70\x72\x65\x73\163\137\156\x65\x77"), "\x6d\x65\164\150\x6f\144" => "\x50\x4f\x53\x54", "\141\x74\164\x72" => ["\151\144" => "\x6e\x65\167\x2d\167\x6f\x72\144\x70\x72\145\163\163\x2d\163\x69\164\x65\x2d\146\x6f\162\x6d"]]); goto f8808; f8808: $form->add("\163\x75\x62\155\x69\164", SubmitType::class, ["\x61\x74\x74\x72" => ["\143\x6c\141\x73\x73" => "\x62\164\x6e\40\x62\164\156\55\154\x67\40\142\164\156\x2d\x62\154\x75\x65"], "\x6c\141\142\x65\x6c" => "\x43\162\145\141\164\x65"]); goto fd6d3; d64a0: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto eeb3c; e38f4: goto dec81; goto a0fce; a0fce: ba79b: goto d620c; f1375: $this->formErrors = $this->getErrorMessages($form); goto e38f4; b8b8e: dec81: goto ffffd; eeb3c: if (true === $form->isValid()) { goto ba79b; } goto f1375; d620c: try { goto F7b91; E2618: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a6c79; B940a: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto d14e6; A5388: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Bb6f8; E2325: $generatedName = $this->generateNameFromDomainName($domainName); goto c9476; Ddb1d: $siteUserPassword = $form->get("\x73\x69\x74\x65\x55\x73\145\x72\120\141\163\163\167\157\162\144")->getData(); goto d87c6; ea554: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto a49f7; F0396: $databaseManager->createDatabase($databaseEntity); goto Cdf4e; dac5a: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto E2cb6; } goto e8493; F5c80: $siteCredentials["\127\x6f\x72\144\x50\x72\x65\x73\x73"] = [$this->translator->trans("\x41\144\x6d\x69\x6e\x20\105\x2d\115\x61\x69\x6c") => $adminEmail, $this->translator->trans("\101\144\x6d\151\156\x20\x55\x73\145\162\40\x4e\x61\155\x65") => $adminUserName, $this->translator->trans("\101\144\155\151\x6e\x20\120\141\163\x73\x77\157\162\x64") => $adminPassword, $this->translator->trans("\x41\144\155\151\156\40\125\162\x6c") => sprintf("\150\164\x74\160\x73\x3a\57\57\45\x73\x2f\x77\160\55\141\x64\x6d\151\156\57", rtrim($domainName, "\x2f"))]; goto D55cd; d90cc: $siteEntity->addDatabase($databaseEntity); goto f9e46; D9d36: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto ac730; d14e6: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto ee54a; c9476: $siteUser = $form->get("\163\x69\164\x65\x55\163\x65\x72")->getData(); goto Ddb1d; b1ff6: $domainName = $form->get("\144\x6f\155\141\x69\x6e\x4e\141\155\x65")->getData(); goto E2325; e9f91: $databaseEntity->setSite($siteEntity); goto D9d36; E2aa1: return $response; goto Ab5ec; ac9b8: $adminPassword = $form->get("\x61\144\x6d\x69\156\120\x61\x73\x73\167\x6f\162\144")->getData(); goto d843f; ee54a: $url = sprintf("\x68\164\164\x70\163\72\x2f\x2f\x25\x73", $siteEntity->getDomainName()); goto ae47f; A0509: $adminUserName = $form->get("\x61\x64\x6d\x69\156\x55\x73\x65\x72\x4e\x61\x6d\x65")->getData(); goto ac9b8; cc742: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto f8b81; e8493: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto ec2f6; a6c79: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Cc2c4; a683a: $databaseEntity->addUser($databaseUserEntity); goto d90cc; Ebdf7: $this->siteEntityManager->updateEntity($siteEntity); goto cc742; ae47f: $title = $form->get("\x73\x69\x74\145\124\x69\x74\154\145")->getData(); goto A0509; Cc2c4: $instance = $request->attributes->get("\151\x6e\x73\x74\141\x6e\143\x65"); goto Aa1de; F7b91: $user = $this->getUser(); goto ec675; ec2f6: E2cb6: goto E2618; Bb6f8: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Dd3ae; d87c6: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto E73e8; a341e: $databaseEntity->setName($databaseName); goto e9f91; Aa881: $isMultiSite = $form->get("\x6d\165\154\x74\x69\x53\x69\164\x65")->getData(); goto A5388; ac730: $databaseUserEntity->setUserName($databaseUserName); goto F2f0a; f9c43: $databaseName = $this->getUniqueDatabaseName($generatedName); goto B940a; ec675: $session = $request->getSession(); goto b1ff6; a3ba3: $eventData = ["\x73\151\164\145" => $domainName, "\163\151\164\x65\x55\163\145\x72" => $siteUser]; goto ea554; E73e8: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto bc1a4; d843f: $adminEmail = $form->get("\141\144\155\x69\x6e\105\155\141\x69\154")->getData(); goto Aa881; f9e46: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto F0396; A286a: $session->set("\x73\x69\x74\x65\103\x72\145\x64\x65\x6e\x74\151\141\154\163", $siteCredentials); goto a3ba3; cdc50: if (!(false === is_null($siteEntity))) { goto c36c1; } goto f9c43; Dd3ae: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto a341e; f8b81: $siteCredentials[$this->translator->trans("\104\x61\164\141\142\141\x73\145")] = [$this->translator->trans("\x48\x6f\163\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\x6f\x72\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\164\141\x62\141\163\x65\x20\x4e\x61\155\x65") => $databaseName, $this->translator->trans("\x44\x61\164\141\x62\141\x73\145\x20\x55\x73\x65\x72\40\116\x61\x6d\145") => $databaseUserName, $this->translator->trans("\104\141\164\141\x62\x61\x73\x65\40\x55\x73\145\x72\40\x50\141\163\163\x77\x6f\x72\144") => $databaseUserPassword]; goto F5c80; Aa1de: $siteCredentials = [$this->translator->trans("\123\x69\164\x65") => [$this->translator->trans("\111\120\x20\x41\144\x64\x72\145\x73\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\104\157\155\141\151\x6e\x20\x4e\141\x6d\x65") => sprintf("\x68\x74\x74\x70\x73\x3a\x2f\x2f\45\163", $domainName), $this->translator->trans("\123\x69\x74\x65\40\x55\163\145\x72") => $siteUser, $this->translator->trans("\x50\141\163\x73\167\157\x72\x64") => $siteUserPassword]]; goto cdc50; ec39f: $databaseUserEntity->setDatabase($databaseEntity); goto a683a; bc1a4: $varnishCacheSettings = []; goto dac5a; F3720: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto ec39f; Cdf4e: $databaseManager->createUser($databaseUserEntity); goto Ebdf7; F2f0a: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto F3720; D55cd: c36c1: goto A286a; a49f7: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\163\x69\164\x65\137\167\x6f\x72\144\x70\x72\145\163\x73\137\151\156\x73\x74\x61\154\154\145\144")); goto E2aa1; Ab5ec: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\x67\x65\x72", $this->translator->trans("\x41\156\40\x65\x72\162\157\162\x20\x68\141\163\x20\157\x63\143\165\x72\162\145\x64\54\40\x65\x72\x72\x6f\162\40\x6d\145\163\x73\x61\147\145\72\x20\x25\145\162\x72\157\x72\x4d\x65\163\163\x61\x67\145\x25", ["\45\x65\162\162\x6f\x72\115\145\x73\163\141\147\x65\45" => $e->getMessage()])); } goto b8b8e; ffffd: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto B48bc; bb9e5: if (!(true === $isMultiSite)) { goto E6e17; } goto D39b8; B0f2d: E6e17: goto a223b; Aa6f1: c7522: goto bb9e5; a5815: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto Cc20b; C2adc: $databaseUserName = $databaseUserEntity->getUserName(); goto a5815; Cc20b: $wordPressInstaller = new WordPressInstaller($siteEntity); goto fe196; a223b: $wordPressInstaller->resetPermissions(); goto A1850; E1952: b458d: goto B0f2d; Ed5c5: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto E2515; D39b8: $this->wordPressMultiSiteConfigValues["\104\117\x4d\x41\111\116\137\x43\x55\122\x52\x45\x4e\x54\137\x53\111\x54\x45"]["\166\x61\154\165\x65"] = $siteEntity->getDomainName(); goto e2f24; E2515: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\141\154\x75\145"], $config["\162\x61\x77"]); Ab4fd: } goto Aa6f1; fe196: $wordPressInstaller->downloadAndExtractLatestVersion(); goto D2e9a; B48bc: $databaseHost = sprintf("\45\163\x3a\45\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto c97e7; e2f24: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\166\x61\154\165\145"], $config["\x72\141\x77"]); A69e9: } goto E1952; c97e7: $databaseName = $databaseEntity->getName(); goto C2adc; D2e9a: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto Ed5c5; A1850: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto f402b; Edcd7: $subjectAlternativeNames[] = $registrableDomain; goto Ee5eb; D4a11: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d56d6; dd547: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E1af0; Be750: $this->siteEntityManager->updateEntity($siteEntity); goto E1f1b; A6eaf: $phpSiteCreator->createRootDirectory(); goto Feae3; Dfa55: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Daf42; A0def: $subjectAlternativeNames[] = sprintf("\x77\x77\x77\x2e\x25\163", $domainName); goto eeee4; a04e3: $siteEntity->setRootDirectory($rootDirectory); goto f97c0; d82d1: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto b4025; E1f1b: return $siteEntity; goto Da88a; fea64: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F8eb3; e2534: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D33cc; Ad3eb: $phpSettingsEntity->setSite($siteEntity); goto Acc6e; b7ef3: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\x2f")), "\57"); goto fea64; Dd896: a63a7: goto b2de7; ff2b2: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Fe755; e7da1: $phpSite->setDomainName($domainName); goto A8b0a; A74d1: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto c1bfb; e51b9: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto e7da1; Bed26: $phpSettingsEntity = new PhpSettingsEntity(); goto c1867; Feae3: $phpSiteCreator->createLogrotateFile(); goto F02c2; c27c3: $phpSite->setPhpSettings($phpSettingsEntity); goto b253b; F381d: $constraintViolationList->addAll($siteConstraints); goto C445a; d56d6: $subdomain = false === empty($subdomain) ? $subdomain : null; goto A132c; A90c4: $certificateEntity = $this->certificateEntityManager->createEntity(); goto d2f3c; Ee5eb: ff074: goto E9d14; Cc8c0: $certificateEntity->setCsr($csr); goto d5af1; A7729: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ff2b2; E1af0: if (!(false === empty($redirectionVhostTemplate))) { goto ff06e; } goto f4e18; f97c0: if (!(false === empty($varnishCache))) { goto c500e; } goto C87e1; A132c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto e2534; B0b21: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto B42f1; bddfa: ff06e: goto C996f; Fe755: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto D8d0b; Fc51b: $defaultVarnishCacheSettings = ["\x65\x6e\141\x62\x6c\x65\144" => false, "\163\x65\162\166\x65\x72" => self::VARNISH_CACHE_SERVER, "\x63\x61\143\150\x65\x54\x61\147\120\x72\x65\146\x69\170" => substr(md5(time()), 0, 4)]; goto d82d1; E9d14: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto f72fb; Afdb4: $vhostTemplate->resetProcessors(); goto A7729; abd1e: $phpSite->setVarnishCache(true); goto Fc51b; E8b25: $siteEntity->setCertificate($certificateEntity); goto E9783; a4afe: $phpSiteCreator->createPhpFpmPool(); goto ce9e3; d2f3c: $certificateEntity->setSite($siteEntity); goto B3560; f3e98: $siteEntity->setUserPassword($siteUserPassword); goto a04e3; d5af1: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto A33ab; b253b: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto F4507; c77c2: $vhostTemplate = new PhpVhostTemplate($phpSite); goto f2bac; f3267: $phpSiteCreator->createPrivateKeyAndCertificate(); goto a4afe; F857c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\x2e\56\x2f\x2e\56\x2f\x72\145\163\x6f\165\162\x63\x65\163\x2f\156\x67\x69\x6e\170\x2f\166\x68\x6f\x73\164\x5f\164\x65\155\160\154\141\164\145\x2f\x72\145\x64\151\162\x65\143\164"); goto B0993; eeee4: e36b0: goto df884; Bbdf3: $phpSite->setCertificate($certificateEntity); goto c27c3; b1a00: c500e: goto B8d38; B42f1: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto Af96c; } goto a0e6f; A3829: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto cce07; d5f41: $siteEntity->setType(SiteEntity::TYPE_PHP); goto Cf4d4; e6024: if (!(true === $varnishCache)) { goto ed3ee; } goto abd1e; C996f: b1993: goto b227c; B8d38: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto b1993; } goto Dacda; A33ab: $certificateEntity->setCertificate($selfSignedCertificate); goto E8b25; D3a32: $phpSiteCreator->createUser(); goto A6eaf; F8eb3: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D4a11; Dacda: if (true === isset($_ENV["\101\120\x50\137\x48\124\124\120\63"]) && "\x74\x72\165\145" === $_ENV["\x41\120\120\137\x48\124\124\x50\63"]) { goto a63a7; } goto F857c; b2de7: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\x2e\x2e\57\56\56\x2f\x72\145\163\157\x75\162\143\145\163\x2f\x6e\147\151\x6e\x78\57\x76\x68\157\163\x74\x5f\164\x65\155\x70\154\141\x74\x65\x2f\162\145\x64\151\162\145\143\x74\x2d\x68\164\164\160\63"); goto f265a; ae14a: Af96c: goto A90c4; Cd5be: if (!(true === is_null($subdomain))) { goto e36b0; } goto A0def; a0e6f: $constraintViolationList = new ConstraintViolationList(); goto F381d; cce07: $certificateEntity->setDefaultCertificate(true); goto b441f; B2cf5: $phpSite->setUser($siteEntity->getUser()); goto e51b9; f9a96: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto c719a; fe4a1: $phpSettingsEntity->setPhpVersion($phpVersion); goto Ad3eb; B0993: goto Df041; goto Dd896; b227c: $siteEntity->setVhostTemplate($vhostTemplate); goto Bed26; b4025: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto f9a96; B9956: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto Bbdf3; E9783: $phpSite = new PhpSite(); goto B2cf5; ce9e3: $phpSiteCreator->reloadPhpFpmService(); goto e6024; C87e1: $siteEntity->setVarnishCache(true); goto b1a00; Daf42: $subjectAlternativeNames = []; goto Cd5be; D8d0b: $vhostTemplate->build(); goto A74d1; Ed140: $csr = $csrGenerator->generate(); goto A3829; f265a: Df041: goto dd547; c719a: ed3ee: goto a0296; D33cc: $siteEntity = $this->siteEntityManager->createEntity(); goto d5f41; b8688: $phpSiteCreator->reloadNginxService(); goto fe10d; f72fb: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Ed140; F02c2: $phpSiteCreator->createIndexPhp(); goto f3267; C445a: $constraintViolationList->addAll($phpSettingsConstraints); goto e888e; a0296: $phpSiteCreator->createNginxVhost(); goto b8688; A8b0a: $phpSite->setRegistrableDomain($registrableDomain); goto c688a; f402b: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto b7ef3; Ee458: $siteEntity->setUser($siteUser); goto f3e98; Acc6e: $siteConstraints = $this->validator->validate($siteEntity); goto B0b21; c1bfb: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Be750; b441f: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Cc8c0; Cf4d4: $siteEntity->setDomainName($domainName); goto Ee458; fe10d: $phpSiteCreator->resetPermissions(); goto c77c2; df884: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto ff074; } goto Edcd7; e888e: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto a3cab; c688a: $phpSite->setSubdomain($subdomain); goto B9956; a3cab: throw new \Exception(implode("\x3b\40", $errorMessages)); goto ae14a; B3560: $rsaKeyGenerator = new RsaKeyGenerator(); goto Dfa55; f4e18: $vhostTemplate = sprintf("\x25\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto bddfa; F4507: $phpSiteCreator = new PhpSiteCreator($phpSite); goto D3a32; f2bac: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Afdb4; c1867: $siteEntity->setPhpSettings($phpSettingsEntity); goto fe4a1; Da88a: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ed777; Ed777: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto B9109; Afe1c: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto dd53d; abf17: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto bb1ad; c92eb: Eb355: goto c6e11; Eaa6e: $siteEntity->setDomainName($domainName); goto Ce5fe; Dea50: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto C39d7; ed729: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto f61a5; cd779: throw new \Exception(implode("\x3b\40", $errorMessages)); goto c92eb; dcff4: $constraintViolationList->addAll($siteConstraints); goto a8849; Fdeb1: $vhostTemplate->build(); goto abf17; Bc7c7: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto Dea50; dfe76: $nodejsSiteCreator->installNodejs(); goto F9324; Ce5fe: $siteEntity->setUser($siteUser); goto D5e1a; c5fe6: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Fdeb1; cb04c: $subjectAlternativeNames[] = $registrableDomain; goto cace1; cace1: a7e45: goto Fab2b; F04fb: Ddc14: goto D4c89; D4b51: $certificateEntity->setCertificate($selfSignedCertificate); goto f68eb; d411e: F2a59: goto F04fb; e7e25: goto D6203; goto c206b; E56d2: $nodejsSiteCreator->reloadNginxService(); goto bcfec; c095d: $certificateEntity->setCsr($csr); goto fb157; c8d96: $nodejsSiteCreator->createUser(); goto E3da8; bf289: $nodejsSiteCreator->createNginxVhost(); goto E56d2; E3da8: $nodejsSiteCreator->createRootDirectory(); goto Dd66b; fcf7b: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto c095d; c90f2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A58e5; a8849: $constraintViolationList->addAll($nodejsSettingsConstraints); goto A0678; B9109: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto A33ca; db846: $nodejsSettingsEntity->setSite($siteEntity); goto F7deb; d7738: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto D2fd5; C39d7: $nodejsSettingsEntity->setPort($port); goto db846; a1839: $siteEntity->setRootDirectory($domainName); goto F2cf3; A2bd9: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto a7e45; } goto cb04c; C578d: $constraintViolationList = new ConstraintViolationList(); goto dcff4; d1a2c: D6203: goto c90f2; c206b: E89d4: goto fd372; c6e11: $certificateEntity = $this->certificateEntityManager->createEntity(); goto e78f8; Fab2b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F1be4; c0d48: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto Eb355; } goto C578d; ab7ad: $nodejsSite->setRegistrableDomain($registrableDomain); goto b4867; D2fd5: $certificateEntity->setDefaultCertificate(true); goto fcf7b; f8214: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ed729; F1be4: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto E0f6c; fd372: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\x2e\x2e\57\56\56\x2f\x72\145\163\157\165\x72\x63\x65\x73\57\156\147\151\156\x78\57\166\150\x6f\x73\x74\x5f\x74\145\x6d\160\x6c\141\x74\145\57\x72\x65\x64\x69\x72\145\x63\x74\x2d\150\x74\x74\x70\63"); goto d1a2c; A5500: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto c5fe6; A33ca: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f8214; d2f94: $nodejsSite = new NodejsSite(); goto d0a2d; E0f6c: $csr = $csrGenerator->generate(); goto d7738; A8cd5: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto d411e; db797: $this->siteEntityManager->updateEntity($siteEntity); goto e6f2b; fb157: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto D4b51; C4f6e: if (!(true === is_null($subdomain))) { goto f5d8d; } goto C64b8; febba: $siteEntity = $this->siteEntityManager->createEntity(); goto ef0d3; e78f8: $certificateEntity->setSite($siteEntity); goto b71cf; d22f0: if (true === isset($_ENV["\x41\x50\120\x5f\110\x54\124\x50\63"]) && "\164\x72\x75\x65" === $_ENV["\101\x50\120\137\x48\124\124\120\x33"]) { goto E89d4; } goto D5548; d0a2d: $nodejsSite->setUser($siteEntity->getUser()); goto ee365; F8e31: $vhostTemplate->resetProcessors(); goto b7bcb; b71cf: $rsaKeyGenerator = new RsaKeyGenerator(); goto Afe1c; F7deb: $siteConstraints = $this->validator->validate($siteEntity); goto B6ae3; Bb302: $nodejsSite->setDomainName($domainName); goto ab7ad; B6ae3: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto c0d48; bb1ad: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto db797; Dd66b: $nodejsSiteCreator->createLogrotateFile(); goto a9bae; Da747: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto c8d96; D5548: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\x2f\56\56\x2f\162\145\x73\157\165\162\143\x65\x73\57\x6e\147\x69\156\x78\57\x76\150\x6f\x73\x74\x5f\164\145\x6d\x70\154\x61\164\x65\x2f\x72\145\x64\151\162\x65\x63\x74"); goto e7e25; ef0d3: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto Eaa6e; A58e5: if (!(false === empty($redirectionVhostTemplate))) { goto F2a59; } goto A8cd5; F2cf3: if (!(true === is_null($subdomain) || "\x77\x77\x77" == $subdomain)) { goto Ddc14; } goto d22f0; Bd594: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Da747; A0678: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto cd779; f68eb: $siteEntity->setCertificate($certificateEntity); goto d2f94; D0624: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto Bd594; b4867: $nodejsSite->setSubdomain($subdomain); goto De519; C64b8: $subjectAlternativeNames[] = sprintf("\x77\167\x77\56\45\163", $domainName); goto E4b3b; b7bcb: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto A5500; Bcf9b: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto f15c3; F9324: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto bf289; dd53d: $subjectAlternativeNames = []; goto C4f6e; f15c3: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto F8e31; bcfec: $nodejsSiteCreator->resetPermissions(); goto Bcf9b; De519: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto d4bfa; a9bae: $nodejsSiteCreator->createNvmDirectory(); goto dfe76; f61a5: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto febba; e6f2b: return $siteEntity; goto Eebea; d4bfa: $nodejsSite->setCertificate($certificateEntity); goto D0624; ee365: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto Bb302; D4c89: $siteEntity->setVhostTemplate($vhostTemplate); goto Bf08e; Bf08e: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto Bc7c7; E4b3b: f5d8d: goto A2bd9; D5e1a: $siteEntity->setUserPassword($siteUserPassword); goto a1839; Eebea: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto B7971; C1528: $pythonSiteCreator->resetPermissions(); goto Ae1a4; Bd192: Ca49f: goto B25cc; de4dc: $pythonSiteCreator->createRootDirectory(); goto b5830; Df6b7: $siteEntity->setPythonSettings($pythonSettingsEntity); goto D52c8; Eb723: if (!(true === is_null($subdomain))) { goto B5f7a; } goto C44bc; Bd391: b33c9: goto B3ef3; A4dbb: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto D0938; B7971: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Ea1ff; Fee47: d662b: goto Ef033; Ea1ff: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto ed1db; E945b: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto aadd9; cbf39: $rsaKeyGenerator = new RsaKeyGenerator(); goto b9321; Bc8a4: $subjectAlternativeNames[] = $registrableDomain; goto Fee47; Cb135: $pythonSite->setPythonSettings($pythonSettingsEntity); goto Cc21c; D072b: $siteEntity->setCertificate($certificateEntity); goto F148d; C2321: $pythonSettingsEntity->setPort($port); goto c4f38; ed1db: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b4e3e; e3404: $certificateEntity->setCertificate($selfSignedCertificate); goto D072b; D9673: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto fe711; a00ad: if (true === isset($_ENV["\x41\x50\120\137\x48\124\124\x50\63"]) && "\164\x72\165\145" === $_ENV["\x41\x50\x50\x5f\x48\x54\x54\x50\x33"]) { goto e9d3b; } goto c7654; e5028: $pythonSite->setUser($siteEntity->getUser()); goto b1083; Dc5bb: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Bb2d6; c264e: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto fa16e; e654e: $csr = $csrGenerator->generate(); goto A405a; acda0: e9d3b: goto ecb70; F2a32: $pythonSiteCreator->reloadNginxService(); goto C1528; fb3b6: $constraintViolationList->addAll($siteConstraints); goto E301b; C727b: $pythonSite->setCertificate($certificateEntity); goto Cb135; D8f6d: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto A1774; aadd9: return $siteEntity; goto Bf518; bc2f1: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Ac592; f49a7: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto de416; A68ce: $siteEntity->setRootDirectory($domainName); goto F6ca1; c66e1: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto d8889; E37b8: $certificateEntity->setSite($siteEntity); goto cbf39; Cc325: B5f7a: goto B0e21; adb08: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto ec723; Ce4f8: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D112d; D1ba1: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto B840a; A1774: $pythonSiteCreator->createNginxVhost(); goto F2a32; B3ef3: $certificateEntity = $this->certificateEntityManager->createEntity(); goto E37b8; b4e3e: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Bdbec; b9321: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto B5526; de416: $this->siteEntityManager->updateEntity($siteEntity); goto E945b; A789f: c4bd1: goto Ad75f; ace98: if (!(false === empty($redirectionVhostTemplate))) { goto F4098; } goto A4dbb; B5526: $subjectAlternativeNames = []; goto Eb723; Cdf96: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e654e; Ef033: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Cdf96; B6d3d: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto C727b; c4f38: $pythonSettingsEntity->setSite($siteEntity); goto Ed2ef; Ae1a4: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto Ce4f8; B25cc: $siteEntity->setVhostTemplate($vhostTemplate); goto c8b7a; fb251: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto F3c02; A1f90: $pythonSiteCreator->writePythonVersionFile(); goto D8f6d; ac077: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e3404; c8b7a: $pythonSettingsEntity = new PythonSettingsEntity(); goto Df6b7; c55fc: $certificateEntity->setDefaultCertificate(true); goto bc2f1; b5830: $pythonSiteCreator->createLogrotateFile(); goto A1f90; b1083: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto aba82; ecb70: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\x2e\57\x2e\56\57\x72\145\163\157\x75\x72\143\x65\x73\57\x6e\147\x69\x6e\x78\57\166\x68\157\x73\x74\x5f\164\x65\155\x70\x6c\x61\164\145\x2f\162\145\144\151\162\x65\143\x74\x2d\150\164\x74\x70\63"); goto A789f; c2869: $siteEntity->setUserPassword($siteUserPassword); goto A68ce; B840a: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto b33c9; } goto b56f5; ec723: $pythonSiteCreator->createUser(); goto de4dc; Ed2ef: $siteConstraints = $this->validator->validate($siteEntity); goto D1ba1; F6ca1: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto Ca49f; } goto a00ad; D0938: F4098: goto Bd192; b56f5: $constraintViolationList = new ConstraintViolationList(); goto fb3b6; aba82: $pythonSite->setDomainName($domainName); goto d4756; D112d: $vhostTemplate->resetProcessors(); goto c264e; Bb2d6: throw new \Exception(implode("\73\40", $errorMessages)); goto Bd391; fa16e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto fb251; Cc21c: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto adb08; D52c8: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto C2321; Ac592: $certificateEntity->setCsr($csr); goto ac077; B7579: $pythonSite->setSubdomain($subdomain); goto B6d3d; Bdbec: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto D9673; E301b: $constraintViolationList->addAll($pythonSettingsConstraints); goto Dc5bb; F148d: $pythonSite = new PythonSite(); goto e5028; C44bc: $subjectAlternativeNames[] = sprintf("\167\x77\x77\56\45\x73", $domainName); goto Cc325; a5f4f: $siteEntity->setUser($siteUser); goto c2869; Ad75f: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto ace98; c7654: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\x2e\x2e\x2f\x2e\56\57\x72\145\163\157\165\x72\x63\145\x73\57\x6e\147\x69\156\x78\x2f\x76\x68\x6f\x73\164\137\x74\x65\155\160\x6c\141\x74\145\x2f\162\145\x64\151\x72\145\x63\x74"); goto c6946; c6946: goto c4bd1; goto acda0; B0e21: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto d662b; } goto Bc8a4; A405a: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c55fc; d8889: $siteEntity->setDomainName($domainName); goto a5f4f; F3c02: $vhostTemplate->build(); goto f49a7; fe711: $siteEntity = $this->siteEntityManager->createEntity(); goto c66e1; d4756: $pythonSite->setRegistrableDomain($registrableDomain); goto B7579; Bf518: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ef13d; A7f77: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto e68b1; a8644: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Ec751; B8842: $certificateEntity->setCsr($csr); goto B9741; E97f8: $siteConstraints = $this->validator->validate($siteEntity); goto C8f49; B0637: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Ce577; cdde0: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto F143b; D55b6: if (!(true === is_null($subdomain))) { goto b187b; } goto da5da; d7cb7: $staticSiteCreator->createRootDirectory(); goto F9920; C092b: $siteEntity = $this->siteEntityManager->createEntity(); goto C4e70; B358f: $staticSiteCreator->createIndexHtml(); goto F7b02; fde47: $staticSiteCreator->resetPermissions(); goto Ddb23; c6082: $constraintViolationList->addAll($siteConstraints); goto bbe30; abbd4: dd6f3: goto D7ac8; Bbf27: $certificateEntity->setSite($siteEntity); goto Db94d; e5c85: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto C092b; D7ac8: $siteEntity->setVhostTemplate($vhostTemplate); goto E97f8; aba3e: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto e482e; A07e4: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Bfc1e; Ec346: $subjectAlternativeNames = []; goto D55b6; Ec751: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B33c3; fb095: $constraintViolationList = new ConstraintViolationList(); goto c6082; A4340: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a8644; da5da: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\x73", $domainName); goto F24af; b2881: $staticSite = new StaticSite(); goto F4f73; B9741: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Bc550; c89f3: d6115: goto B0637; A5cf2: $siteEntity->setUser($siteUser); goto da3a5; Aeb40: return $siteEntity; goto fd654; Bfc1e: $vhostTemplate->resetProcessors(); goto A7f77; e482e: $certificateEntity->setDefaultCertificate(true); goto e2d04; F37bc: $csr = $csrGenerator->generate(); goto aba3e; b2972: if (!(true === is_null($subdomain) || "\167\167\167" == $subdomain)) { goto dd6f3; } goto b364a; cb296: $this->siteEntityManager->updateEntity($siteEntity); goto Aeb40; eabef: $staticSite->setRegistrableDomain($registrableDomain); goto C6aea; Bd562: $siteEntity->setCertificate($certificateEntity); goto b2881; C948c: ebe67: goto f3dfa; ad072: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Ec346; B95a7: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto C70bb; e68b1: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto e7d2b; Aab1d: b21bf: goto fadfe; D4ade: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto d6115; } goto C6b4d; e42a3: $vhostTemplate->build(); goto cdde0; da3a5: $siteEntity->setUserPassword($siteUserPassword); goto bde17; E522d: $staticSiteCreator->reloadNginxService(); goto fde47; aabd9: $staticSiteCreator->createUser(); goto d7cb7; Bc550: $certificateEntity->setCertificate($selfSignedCertificate); goto Bd562; F143b: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto cb296; C6b4d: $subjectAlternativeNames[] = $registrableDomain; goto c89f3; e2d04: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto B8842; Ce577: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F37bc; Ef13d: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto A4340; B5d9d: $staticSiteCreator = new StaticSiteCreator($staticSite); goto aabd9; C4e70: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto E8c9d; F24af: b187b: goto D4ade; bde17: $siteEntity->setRootDirectory($domainName); goto b2972; Ef2e0: $staticSite->setDomainName($domainName); goto eabef; f3dfa: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\56\56\57\x2e\56\x2f\162\x65\163\x6f\x75\162\x63\145\x73\x2f\156\x67\x69\x6e\x78\57\166\x68\x6f\x73\x74\x5f\x74\145\x6d\160\154\141\164\145\57\162\x65\x64\x69\x72\x65\x63\x74\x2d\x68\164\164\x70\x33"); goto ab5e1; Ce5c5: $vhostTemplate = sprintf("\x25\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto f907d; fadfe: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Bbf27; c8355: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto Ef2e0; F7b02: $staticSiteCreator->createPrivateKeyAndCertificate(); goto Ecce8; C70bb: $staticSite->setCertificate($certificateEntity); goto da418; F4f73: $staticSite->setUser($siteEntity->getUser()); goto c8355; Db94d: $rsaKeyGenerator = new RsaKeyGenerator(); goto ad072; ab5e1: F7981: goto F4429; bbe30: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto C7e46; b364a: if (true === isset($_ENV["\101\120\x50\x5f\x48\x54\124\x50\63"]) && "\164\x72\x75\x65" === $_ENV["\x41\x50\x50\x5f\110\x54\x54\x50\x33"]) { goto ebe67; } goto c3410; da418: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B5d9d; F9920: $staticSiteCreator->createLogrotateFile(); goto B358f; E8c9d: $siteEntity->setDomainName($domainName); goto A5cf2; B33c3: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto e5c85; Ecce8: $staticSiteCreator->createNginxVhost(); goto E522d; C7e46: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Aab1d; bf458: if (!(false === empty($redirectionVhostTemplate))) { goto d3f3a; } goto Ce5c5; f907d: d3f3a: goto abbd4; C6aea: $staticSite->setSubdomain($subdomain); goto B95a7; e7d2b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto e42a3; Ddb23: $vhostTemplate = new StaticVhostTemplate($staticSite); goto A07e4; F4429: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto bf458; c3410: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\56\x2e\x2f\x2e\56\57\162\x65\163\x6f\165\162\x63\145\163\x2f\156\147\x69\x6e\170\x2f\x76\150\x6f\163\x74\137\164\145\x6d\160\x6c\141\x74\145\57\x72\x65\144\x69\162\145\143\x74"); goto F4370; F4370: goto F7981; goto C948c; C8f49: if (!count($siteConstraints)) { goto b21bf; } goto fb095; fd654: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto A2151; a16dd: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Fd20e; B8bbf: if (!count($siteConstraints)) { goto f0c44; } goto f8559; Ac616: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\45\x73", $domainName); goto c87bb; c94ce: $subjectAlternativeNames[] = $registrableDomain; goto e1150; e1022: if (true === isset($_ENV["\101\x50\x50\137\x48\x54\124\x50\63"]) && "\164\162\165\x65" === $_ENV["\x41\x50\x50\x5f\x48\124\x54\120\x33"]) { goto a3228; } goto e8477; eba9c: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto E9a27; b50a7: a3228: goto B27d4; efd3b: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ac0f1; b6d02: $siteEntity->setDomainName($domainName); goto c995a; f689f: $reverseProxySite->setDomainName($domainName); goto A10f3; Fb66c: $reversProxySiteCreator->createNginxVhost(); goto A9f16; E55d6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto ad6d0; fbade: if (!(false === empty($redirectionVhostTemplate))) { goto Ef137; } goto dfa6f; Baba3: $reverseProxySite->setUser($siteEntity->getUser()); goto Aad85; C5ce1: return $siteEntity; goto E4b90; f4a9a: $siteEntity->setUserPassword($siteUserPassword); goto Ac596; fe779: $reverseProxySite->setCertificate($certificateEntity); goto eba9c; C1f92: $certificateEntity->setCertificate($selfSignedCertificate); goto f38b9; A10f3: $reverseProxySite->setRegistrableDomain($registrableDomain); goto da44c; F46e7: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto a89ad; F5b82: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto E55d6; E60c6: $reversProxySiteCreator->createLogrotateFile(); goto D3313; c995a: $siteEntity->setUser($siteUser); goto f4a9a; e3242: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C1f92; A2151: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto efd3b; Da735: $certificateEntity->setSite($siteEntity); goto c3d63; Bd0cc: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto fe779; a3996: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto fbade; f2893: $vhostTemplate->build(); goto F5b82; Dd840: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Da735; dfa6f: $vhostTemplate = sprintf("\45\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto B90d3; e8477: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\x2e\x2e\57\x72\145\x73\x6f\x75\x72\x63\x65\163\x2f\x6e\x67\x69\x6e\x78\x2f\x76\150\x6f\163\164\x5f\x74\145\x6d\160\154\x61\x74\x65\x2f\x72\x65\x64\151\x72\x65\x63\x74"); goto bc16d; B28b5: $csr = $csrGenerator->generate(); goto a16dd; D3313: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Fb66c; bbb63: $siteConstraints = $this->validator->validate($siteEntity); goto B8bbf; c2e27: if (!(true === is_null($subdomain))) { goto B5637; } goto Ac616; F8c85: $reversProxySiteCreator->createRootDirectory(); goto E60c6; bc57a: $reversProxySiteCreator->createUser(); goto F8c85; Daebc: E7629: goto a3996; a3e30: $siteEntity->setVhostTemplate($vhostTemplate); goto bbb63; c1cbe: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto Aad98; } goto c94ce; Eb72d: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto bc57a; Fc140: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto b7069; Ac0f1: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F7797; f483a: $constraintViolationList->addAll($siteConstraints); goto c7dce; c3d63: $rsaKeyGenerator = new RsaKeyGenerator(); goto b1bb3; Aad85: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto f689f; c2659: $subjectAlternativeNames = []; goto c2e27; d87d0: $reversProxySiteCreator->resetPermissions(); goto Fc140; ad6d0: $this->siteEntityManager->updateEntity($siteEntity); goto C5ce1; B520a: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto fde4c; A9322: throw new \Exception(implode("\x3b\40", $errorMessages)); goto Df366; a89ad: $certificateEntity->setCsr($csr); goto e3242; d23d7: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B28b5; c87bb: B5637: goto c1cbe; Ac596: $siteEntity->setRootDirectory($domainName); goto ecfa4; b7069: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto f9f4c; A9f16: $reversProxySiteCreator->reloadNginxService(); goto d87d0; f38b9: $siteEntity->setCertificate($certificateEntity); goto dae18; e26ef: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B9b5f; e3c55: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto f2893; D43b9: $siteEntity = $this->siteEntityManager->createEntity(); goto B4ffd; bc16d: goto E7629; goto b50a7; d713b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto d23d7; A512a: dcffd: goto a3e30; B9b5f: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto e3c55; B4ffd: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto b6d02; dae18: $reverseProxySite = new ReverseProxySite(); goto Baba3; f9f4c: $vhostTemplate->resetProcessors(); goto e26ef; Df366: f0c44: goto Dd840; fde4c: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D43b9; ecfa4: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Eea39; f8559: $constraintViolationList = new ConstraintViolationList(); goto f483a; da44c: $reverseProxySite->setSubdomain($subdomain); goto Bd0cc; B90d3: Ef137: goto A512a; c7dce: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto A9322; Fd20e: $certificateEntity->setDefaultCertificate(true); goto F46e7; B27d4: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\x2e\x2f\x2e\56\57\162\x65\163\157\x75\x72\x63\x65\x73\57\156\147\x69\156\x78\57\x76\x68\157\163\x74\137\x74\145\155\160\154\141\x74\145\57\162\x65\144\x69\162\x65\143\x74\x2d\150\x74\x74\160\63"); goto Daebc; F7797: $subdomain = false === empty($subdomain) ? $subdomain : null; goto B520a; E9a27: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto Eb72d; e1150: Aad98: goto d713b; b1bb3: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c2659; Eea39: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto dcffd; } goto e1022; E4b90: } public function installedWordPressSite(Request $request) : Response { goto dff18; F60d9: $response = $this->render("\106\x72\157\156\x74\145\x6e\144\57\123\x69\164\145\57\x4e\145\x77\x2f\x77\157\162\x64\160\162\145\x73\163\55\151\x6e\x73\x74\141\x6c\154\145\x64\56\150\164\155\x6c\x2e\x74\x77\x69\x67", ["\x73\151\164\145\x43\x72\145\x64\145\156\164\151\x61\x6c\x73" => $siteCredentials]); goto A06f9; A06f9: return $response; goto cf3de; dff18: $session = $request->getSession(); goto a3a86; cf3de: a3e57: goto A8f9d; Dc1fc: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto F60d9; ed225: if (false === empty($siteCredentials)) { goto d3fd7; } goto A1e73; a3a86: $siteCredentials = $session->get("\163\x69\164\x65\103\x72\x65\144\x65\x6e\164\x69\141\154\x73"); goto ed225; ed263: goto a3e57; goto B05e7; B05e7: d3fd7: goto Dc1fc; A8f9d: return $response; goto Faadb; A1e73: $response = $this->redirect($this->generateUrl("\x63\154\160\x5f\x73\151\x74\x65\163")); goto ed263; Faadb: } private function renderSiteCredentials(array $siteCredentials) : string { goto a5f47; a0d54: foreach ($siteCredentials as $section => $sectionData) { goto df74d; df74d: $renderedCredentials .= $section . PHP_EOL; goto C8e13; A2701: F9de8: goto Fbd39; Fd63d: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\163\x3a\40\45\x73", $key, $value) . PHP_EOL; efcde: } goto b2ee9; C8e13: $renderedCredentials .= "\x2d\55\x2d\x2d\55\55\55\55\55\55\x2d\x2d\x2d\55\x2d\55\55\x2d\55\55\x2d\x2d\55\55\x2d\x2d\55\x2d\55\55\x2d\55\55\55\55\55\55\55\x2d\55\x2d\55\x2d\x2d\55\x2d\55\x2d\55\x2d\55\55\x2d\55" . PHP_EOL; goto Fd63d; cd6e4: $renderedCredentials .= PHP_EOL; goto A2701; b2ee9: F2ded: goto cd6e4; Fbd39: } goto a6c7d; fc75d: return $renderedCredentials; goto addf8; a5f47: $renderedCredentials = ''; goto a0d54; a6c7d: C2c00: goto fc75d; addf8: } private function getVhostTemplateEntity(string $name) : mixed { goto c03b6; dff80: throw new \Exception($this->translator->trans("\x56\150\157\x73\x74\x20\x54\x65\x6d\160\x6c\141\164\x65\x20\x25\166\x68\157\x73\164\124\x65\x6d\160\x6c\141\164\145\x25\40\144\x6f\x65\163\40\x6e\x6f\164\40\x65\170\151\x73\164\56", ["\x25\x76\150\157\x73\164\x54\145\155\x70\154\141\x74\x65\45" => $name])); goto cceb9; f9d4b: if (!(true === is_null($vhostTemplateEntity))) { goto D4a17; } goto dff80; De19d: return $vhostTemplateEntity; goto C0408; c03b6: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto f9d4b; cceb9: D4a17: goto De19d; C0408: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto F71d3; F71d3: $errorMessages = []; goto Acc46; Acc46: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\45\x73\x3a\40\x25\x73", $constraint->getPropertyPath(), $constraint->getMessage()); dd0cb: } goto a92b0; a92b0: D86d6: goto A38e1; A38e1: return $errorMessages; goto A0ae6; A0ae6: } private function generateNameFromDomainName(string $domainName) : string { goto f1ce9; E6616: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto E188c; A4c90: return $name; goto C932e; e46d5: $name = sprintf("\45\163\x2d\x25\x73", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto e78c3; d018b: if ("\167\167\167" == $subdomain) { goto c2efe; } goto f4936; f392f: $explodedRegistrableDomain = explode("\x2e", $registrableDomain); goto d018b; f1ce9: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto E6616; B0088: $name = $explodedRegistrableDomain[0] ?? ''; goto C096d; C096d: F64de: goto A4c90; E188c: $subdomain = $resolvedDomainName->subDomain()->toString(); goto f392f; c0c57: if (!(false === empty($subdomain))) { goto Af87a; } goto Aace6; f4936: $name = $explodedRegistrableDomain[0] ?? ''; goto c0c57; bf2f9: goto F64de; goto A54e5; A54e5: c2efe: goto B0088; e78c3: Af87a: goto bf2f9; Aace6: $explodedSubdomain = explode("\56", $subdomain); goto e46d5; C932e: } private function getUniqueDatabaseName(string $databaseName) : string { goto e20c5; a4b16: $i = 0; goto Df48a; F355e: cf2d2: goto b2bf5; E4f61: $databaseExists = in_array($uniqueDatabaseName, $databases); goto Ed6f4; Df48a: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto Ee157; C80c3: B677f: goto a4b16; D0eb9: if (true === $databaseExists) { goto cf2d2; } goto E7ca0; E7ca0: d5d1f: goto Ba55a; Ed6f4: $i++; goto D0eb9; f7f3e: e0e11: goto E4f61; Ba55a: return $uniqueDatabaseName; goto e287b; b4131: $uniqueDatabaseName = sprintf("\45\163\x2d\144\x62", $uniqueDatabaseName); goto C80c3; Ee157: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto b82fc; Cd8f0: if (!(strlen($uniqueDatabaseName) <= 3)) { goto B677f; } goto b4131; e20c5: $uniqueDatabaseName = $databaseName; goto Cd8f0; b2bf5: if (!(0 < $i)) { goto e0e11; } goto d2cb6; b82fc: $databases = $databaseConnection->getDatabases(); goto F355e; d2cb6: $uniqueDatabaseName = sprintf("\45\x73\55\45\x73", $databaseName, $i); goto f7f3e; e287b: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto f45bc; cd55f: c724f: goto Aa524; F9f8e: if (!(0 < $i)) { goto C530d; } goto ccc53; b1ad7: C530d: goto c0e6d; D6015: $i = 0; goto f94bd; f94bd: B0963: goto F9f8e; f45bc: $uniqueDatabaseUserName = $databaseUserName; goto f99d2; f99d2: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto Aa0a2; } goto Aae23; ac48d: if (false === is_null($databaseUserEntity)) { goto B0963; } goto cd55f; Aae23: $uniqueDatabaseUserName = sprintf("\45\163\x2d\x64\x62", $uniqueDatabaseUserName); goto ab9ee; Aa524: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto E2dfe; A5be0: $i++; goto ac48d; ccc53: $uniqueDatabaseUserName = sprintf("\x25\x73\x2d\x25\163", $databaseUserName, $i); goto b1ad7; ab9ee: Aa0a2: goto D6015; E2dfe: return $uniqueDatabaseUserName; goto Ac947; c0e6d: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto A5be0; Ac947: } private function hasPermissions() : bool { goto befcc; b74c2: Adaa4: goto Aa92f; b9bed: return true; goto b74c2; D356b: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto Adaa4; } goto b9bed; Aa92f: return false; goto A05db; befcc: $user = $this->getUser(); goto D356b; A05db: } }
